@@ -1,6 +1,10 @@
-# $Id: interleave.R,v 1.3 2002/09/23 13:59:30 warnes Exp $
+# $Id: interleave.R,v 1.4 2003/05/20 16:03:02 warnes Exp $
 #
 # $Log: interleave.R,v $
+# Revision 1.4  2003/05/20 16:03:02  warnes
+#
+# - Omit NULL variables.
+#
 # Revision 1.3  2002/09/23 13:59:30  warnes
 # - Modified all files to include CVS Id and Log tags.
 #
@@ -16,6 +20,8 @@ interleave <- function(..., append.source=TRUE, sep=": ")
   {
     sources <- list(...)
 
+    sources[sapply(sources, is.null)] <- NULL
+
     sources <- lapply(sources, function(x)
                       if(is.matrix(x) || is.data.frame(x))
                       x else t(x) )
